# Copyright (c) 2024 Phase Advanced Sensor Systems, Inc.
from ..device import Device, AReg32


class PWR(Device):
    '''
    Driver for the STM32C0 Power Control (PWR) device.
    '''
    REGS = [AReg32('CR1',           0x000, [('LPMS',            0,  2),
                                            ('FPD_STOP',        3),
                                            ('FPD_SLEEP',       5),
                                            ]),
            AReg32('CR3',           0x008, [('EWUP1',           0),
                                            ('EWUP2',           1),
                                            ('EWUP3',           2),
                                            ('EWUP4',           3),
                                            ('EWUP6',           5),
                                            ('APC',             10),
                                            ('EIWUL',           15),
                                            ]),
            AReg32('CR4',           0x00C, [('WP1',             0),
                                            ('WP2',             1),
                                            ('WP3',             2),
                                            ('WP4',             3),
                                            ('WP6',             5),
                                            ]),
            AReg32('SR1',           0x010, [('WUF1',            0),
                                            ('WUF2',            1),
                                            ('WUF3',            2),
                                            ('WUF4',            3),
                                            ('WUF6',            5),
                                            ]),
            AReg32('SR2',           0x014, [('FLASH_RDY',       7),
                                            ]),
            AReg32('SCR',           0x018, [('CWUF1',           0),
                                            ('CWUF2',           1),
                                            ('CWUF3',           2),
                                            ('CWUF4',           3),
                                            ('CWUF6',           5),
                                            ]),
            AReg32('PUCRA',         0x020, [('PU0',             0),
                                            ('PU1',             1),
                                            ('PU2',             2),
                                            ('PU3',             3),
                                            ('PU4',             4),
                                            ('PU5',             5),
                                            ('PU6',             6),
                                            ('PU7',             7),
                                            ('PU8',             8),
                                            ('PU9',             9),
                                            ('PU10',            10),
                                            ('PU11',            11),
                                            ('PU12',            12),
                                            ('PU13',            13),
                                            ('PU14',            14),
                                            ('PU15',            15),
                                            ]),
            AReg32('PDCRA',         0x024, [('PD0',             0),
                                            ('PD1',             1),
                                            ('PD2',             2),
                                            ('PD3',             3),
                                            ('PD4',             4),
                                            ('PD5',             5),
                                            ('PD6',             6),
                                            ('PD7',             7),
                                            ('PD8',             8),
                                            ('PD9',             9),
                                            ('PD10',            10),
                                            ('PD11',            11),
                                            ('PD12',            12),
                                            ('PD13',            13),
                                            ('PD14',            14),
                                            ('PD15',            15),
                                            ]),
            AReg32('PUCRB',         0x028, [('PU0',             0),
                                            ('PU1',             1),
                                            ('PU2',             2),
                                            ('PU3',             3),
                                            ('PU4',             4),
                                            ('PU5',             5),
                                            ('PU6',             6),
                                            ('PU7',             7),
                                            ('PU8',             8),
                                            ('PU9',             9),
                                            ('PU10',            10),
                                            ('PU11',            11),
                                            ('PU12',            12),
                                            ('PU13',            13),
                                            ('PU14',            14),
                                            ('PU15',            15),
                                            ]),
            AReg32('PDCRB',         0x02C, [('PD0',             0),
                                            ('PD1',             1),
                                            ('PD2',             2),
                                            ('PD3',             3),
                                            ('PD4',             4),
                                            ('PD5',             5),
                                            ('PD6',             6),
                                            ('PD7',             7),
                                            ('PD8',             8),
                                            ('PD9',             9),
                                            ('PD10',            10),
                                            ('PD11',            11),
                                            ('PD12',            12),
                                            ('PD13',            13),
                                            ('PD14',            14),
                                            ('PD15',            15),
                                            ]),
            AReg32('PUCRC',         0x030, [('PU6',             6),
                                            ('PU7',             7),
                                            ('PU13',            13),
                                            ('PU14',            14),
                                            ('PU15',            15),
                                            ]),
            AReg32('PDCRC',         0x034, [('PD6',             6),
                                            ('PD7',             7),
                                            ('PD13',            13),
                                            ('PD14',            14),
                                            ('PD15',            15),
                                            ]),
            AReg32('PUCRD',         0x038, [('PU0',             0),
                                            ('PU1',             1),
                                            ('PU2',             2),
                                            ('PU3',             3),
                                            ]),
            AReg32('PDCRD',         0x03C, [('PD0',             0),
                                            ('PD1',             1),
                                            ('PD2',             2),
                                            ('PD3',             3),
                                            ]),
            AReg32('PUCRF',         0x048, [('PU0',             0),
                                            ('PU1',             1),
                                            ('PU2',             2),
                                            ]),
            AReg32('PDCRF',         0x04C, [('PD0',             0),
                                            ('PD1',             1),
                                            ('PD2',             2),
                                            ]),
            AReg32('BKP0R',         0x070, [('BKP',             0,  15),
                                            ]),
            AReg32('BKP1R',         0x074, [('BKP',             0,  15),
                                            ]),
            AReg32('BKP2R',         0x078, [('BKP',             0,  15),
                                            ]),
            AReg32('BKP3R',         0x07C, [('BKP',             0,  15),
                                            ]),
            ]

    def __init__(self, target, ap, name, addr, **kwargs):
        super().__init__(target, ap, addr, name, PWR.REGS, **kwargs)
