# Copyright (c) 2018-2025 Phase Advanced Sensor Systems, Inc.
from ..device import Device, Reg32


class PWR_2x_3x(Device):
    '''
    Driver for the STM Power Control (PWR) device.
    '''
    REGS = [Reg32('CR1',        0x000, [('LPDS',        1),
                                        ('',            3),
                                        ('PVDE',        1),
                                        ('PLS',         3),
                                        ('DBP',         1),
                                        ('FLPS',        1),
                                        ('',            4),
                                        ('SVOS',        2),
                                        ('AVDEN',       1),
                                        ('ALS',         2),
                                        ]),
            Reg32('CSR1',       0x004, [('',            4),
                                        ('PVDO',        1),
                                        ('',            8),
                                        ('ACTVOSRDY',   1),
                                        ('ACTVOS',      2),
                                        ('AVDO',        1),
                                        ]),
            Reg32('CR2',        0x008, [('BREN',        1),
                                        ('',            3),
                                        ('MONEN',       1),
                                        ('',            11),
                                        ('BRRDY',       1),
                                        ('',            3),
                                        ('VBATL',       1),
                                        ('VBATH',       1),
                                        ('TEMPL',       1),
                                        ('TEMPH',       1),
                                        ]),
            Reg32('CR3',        0x00C, [('BYPASS',      1),
                                        ('LDOEN',       1),
                                        ('SDEN',        1),
                                        ('SDEXTHP',     1),
                                        ('SDLEVEL',     2),
                                        ('',            2),
                                        ('VBE',         1),
                                        ('VBRS',        1),
                                        ('',            6),
                                        ('SDEXTRDY',    1),
                                        ('',            7),
                                        ('USB33DEN',    1),
                                        ('USBREGEN',    1),
                                        ('USB33RDY',    1),
                                        ]),
            Reg32('CPUCR',      0x010, [('PDDS_D1',     1),
                                        ('PDDS_D2',     1),
                                        ('PDDS_D3',     1),
                                        ('',            2),
                                        ('STOPF',       1),
                                        ('SBF',         1),
                                        ('SBF_D1',      1),
                                        ('SBF_D2',      1),
                                        ('CSSF',        1),
                                        ('',            1),
                                        ('RUN_D3',      1),
                                        ]),
            Reg32('D3CR',       0x018, [('',            13),
                                        ('VOSRDY',      1),
                                        ('VOS',         2),
                                        ]),
            Reg32('WKUPCR',     0x020, [('WKUPC1',      1),
                                        ('WKUPC2',      1),
                                        ('',            1),
                                        ('WKUPC4',      1),
                                        ('',            1),
                                        ('WKUPC6',      1),
                                        ]),
            Reg32('WKUPFR',     0x024, [('WKUPF1',      1),
                                        ('WKUPF2',      1),
                                        ('',            1),
                                        ('WKUPF4',      1),
                                        ('',            1),
                                        ('WKUPF6',      1),
                                        ]),
            Reg32('WKUPEPR',    0x028, [('WKUPEN1',     1),
                                        ('WKUPEN2',     1),
                                        ('',            1),
                                        ('WKUPEN4',     1),
                                        ('',            1),
                                        ('WKUPEN6',     1),
                                        ('',            2),
                                        ('WKUPP1',      1),
                                        ('WKUPP2',      1),
                                        ('',            1),
                                        ('WKUPP4',      1),
                                        ('',            1),
                                        ('WKUPP6',      1),
                                        ('',            2),
                                        ('WKUPPUPD1',   2),
                                        ('WKUPPUPD2',   2),
                                        ('',            2),
                                        ('WKUPPUPD4',   2),
                                        ('',            2),
                                        ('WKUPPUPD6',   2),
                                        ]),
            ]

    def __init__(self, target, ap, name, addr, **kwargs):
        super().__init__(target, ap, addr, name, PWR_2x_3x.REGS, **kwargs)
