# Copyright (c) 2024 by Phase Advanced Sensor Systems, Inc.
from ..device import Device, AReg32, Reg8S


class SPI(Device):
    '''
    Driver for the STM32H7 SPI device.
    '''
    REGS = [AReg32('CR1',       0x00,  [('SPE',         0),
                                        ('MASRX',       8),
                                        ('CSTART',      9),
                                        ('CSUSP',       10),
                                        ('HDDIR',       11),
                                        ('SSI',         12),
                                        ('CRC33_17',    13),
                                        ('RCRCINI',     14),
                                        ('TCRCINI',     15),
                                        ('IOLOCK',      16),
                                        ]),
            AReg32('CR2',       0x04,  [('TSIZE',       0,  15),
                                        ('TSER',        16, 31),
                                        ]),
            AReg32('CFG1',      0x08,  [('DSIZE',       0,  4),
                                        ('FTHLV',       5,  8),
                                        ('UDRCFG',      9,  10),
                                        ('UDRDET',      11, 12),
                                        ('RXDMAEN',     14),
                                        ('TXDMAEN',     15),
                                        ('CRCSIZE',     16, 20),
                                        ('CRCEN',       22),
                                        ('MBR',         28, 30),
                                        ]),
            AReg32('CFG2',      0x0C,  [('MSSI',        0,  3),
                                        ('MIDI',        4,  7),
                                        ('IOSWP',       15),
                                        ('COMM',        17, 18),
                                        ('SP',          19, 21),
                                        ('MASTER',      22),
                                        ('LSBFRST',     23),
                                        ('CPHA',        24),
                                        ('CPOL',        25),
                                        ('SSM',         26),
                                        ('SSIOP',       28),
                                        ('SSOE',        29),
                                        ('SSOM',        30),
                                        ('AFCNT',       31),
                                        ]),
            AReg32('IER',       0x10,  [('RXPIE',       0),
                                        ('TXPIE',       1),
                                        ('DXPIE',       2),
                                        ('EOTIE',       3),
                                        ('TXTFIE',      4),
                                        ('UDRIE',       5),
                                        ('OVRIE',       6),
                                        ('CRCEIE',      7),
                                        ('TIFREIE',     8),
                                        ('MODFIE',      9),
                                        ('TSERFIE',     10),
                                        ]),
            AReg32('SR',        0x14,  [('RXP',         0),
                                        ('TXP',         1),
                                        ('DXP',         2),
                                        ('EOT',         3),
                                        ('TXTF',        4),
                                        ('UDR',         5),
                                        ('OVR',         6),
                                        ('CRCE',        7),
                                        ('TIFRE',       8),
                                        ('MODF',        9),
                                        ('TSERF',       10),
                                        ('SUSP',        11),
                                        ('TXC',         12),
                                        ('RXPLVL',      13, 14),
                                        ('RXWNE',       15),
                                        ('CTSIZE',      16, 21),
                                        ]),
            AReg32('IFCR',      0x18,  [('EOTC',        3),
                                        ('TXTFC',       4),
                                        ('UDRC',        5),
                                        ('OVRC',        6),
                                        ('CRCEC',       7),
                                        ('TIFREC',      8),
                                        ('MODFC',       9),
                                        ('TSERFC',      10),
                                        ('SUSPC',       11),
                                        ]),
            Reg8S('TXDR',       0x20,  [('TXDR',        8),
                                        ]),
            Reg8S('RXDR',       0x30,  [('RXDR',        8),
                                        ]),
            AReg32('CRCPOLY',   0x40,  [('CRCPOLY',     0,  31),
                                        ]),
            AReg32('TXCRC',     0x44,  [('TXCRC',       0,  31),
                                        ]),
            AReg32('RXCRC',     0x48,  [('RXCRC',       0,  31),
                                        ]),
            Reg8S('UDRDR',      0x4C,  [('UDRDR',       8),
                                        ]),
            AReg32('I2SCFGR',   0x50,  [('I2SMOD',      0),
                                        ('I2SCFG',      1,  3),
                                        ('I2SSTD',      4,  5),
                                        ('PCMSYNC',     7),
                                        ('DATLEN',      8,  9),
                                        ('CHLEN',       10),
                                        ('CKPOL',       11),
                                        ('FIXCH',       12),
                                        ('WSINV',       13),
                                        ('DATFMT',      14),
                                        ('I2SDIV',      16, 23),
                                        ('ODD',         24),
                                        ('MCKOE',       25),
                                        ]),
            ]

    def __init__(self, target, ap, name, addr, **kwargs):
        super().__init__(target, ap, addr, name, SPI.REGS, **kwargs)
